Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1443)

Unified Diff: sandbox/win/src/lpc_policy.h

Issue 1296223005: Continuing changes for lpc proxy Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sandbox/win/src/lpc_interception.cc ('k') | sandbox/win/src/lpc_policy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sandbox/win/src/lpc_policy.h
diff --git a/sandbox/win/src/process_mitigations_win32k_policy.h b/sandbox/win/src/lpc_policy.h
similarity index 67%
copy from sandbox/win/src/process_mitigations_win32k_policy.h
copy to sandbox/win/src/lpc_policy.h
index 078ed2bee151d23661dd7289f338a7df625182db..4d302332c46a0197e873b662bf530442832907af 100644
--- a/sandbox/win/src/process_mitigations_win32k_policy.h
+++ b/sandbox/win/src/lpc_policy.h
@@ -1,9 +1,9 @@
-// Copyright 2014 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef SANDBOX_SRC_PROCESS_MITIGATIONS_WIN32K_POLICY_H_
-#define SANDBOX_SRC_PROCESS_MITIGATIONS_WIN32K_POLICY_H_
+#ifndef SANDBOX_SRC_LPC_POLICY_H_
+#define SANDBOX_SRC_LPC_POLICY_H_
#include "base/basictypes.h"
#include "sandbox/win/src/crosscall_server.h"
@@ -14,12 +14,12 @@ namespace sandbox {
enum EvalResult;
-// This class centralizes most of the knowledge related to the process
-// mitigations Win32K lockdown policy.
-class ProcessMitigationsWin32KLockdownPolicy {
+// This class centralizes most of the knowledge related to the LPC
+// policy
+class LpcPolicy {
public:
// Creates the required low-level policy rules to evaluate a high-level
- // policy rule for the Win32K process mitigation policy.
+ // policy rule for the LPC policy.
// name is the object name, semantics is the desired semantics for the
// open or create and policy is the policy generator to which the rules are
// going to be added.
« no previous file with comments | « sandbox/win/src/lpc_interception.cc ('k') | sandbox/win/src/lpc_policy.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698